@@ -30,7 +30,7 @@
  * @author Mathieu Parent <sathieu@debian.org>
  * @license Expat http://www.jclark.com/xml/copying.txt
  */
-class BaseCliTest extends PHPUnit_Framework_TestCase {
+class BaseCliTest extends PHPUnit\Framework\TestCase {
     protected $_cli;
     protected $_baseHelp = 'Usage:
     pkgtools COMMAND
